#!/bin/bash

# Packager : Jean-Philippe Guillemin <jp.guillemin@free.fr>
# Sources for perl : http://www.perl.com
# Sources for modules : http://search.cpan.org


VERSION='2.32.0'
BUILD='70.1'
NAME='perl-gtk2'
arch='i486'
cpu='i686'

perlversion="5.12.2"

PKGBUILD=$(pwd)
TMP="$PKGBUILD/tmp"
rm -rf $TMP
mkdir -p $TMP
PKG="/tmp/$NAME-$VERSION-$arch-$BUILD"
rm -f $PKG.tgz
rm -rf $PKG
mkdir -p $PKG

cd $PKGBUILD



# modules:
sources=" \
Gnome2-Canvas \
Gnome2-VFS \
Cairo \
ExtUtils-Depends \
ExtUtils-PkgConfig \
Glib \
Gnome2-1 \
Gnome2-GConf \
Gnome2-Vte \
Gtk2-1 \
Gtk2-GladeXML \
Gtk2-TrayIcon \
Pango "

for source in $sources ; do
  echo -n "Checking $source : "
  cd $PKGBUILD
  tarball="$(ls ${source}*tar* 2>/dev/null)"
  if [ "$tarball" == "" ] ; then
    echo "not found :("
    exit 1
  else
    echo "found $tarball :)"
  fi
done

cd $PKGBUILD
for source in $sources ; do

  cd $PKGBUILD
  tarball="$(ls ${source}*tar* )"

  rm -rf $TMP
  mkdir -p $TMP
  
  tar xvf $tarball -C $TMP
  
  SRC=$(ls -d $TMP/*/)

    cd $SRC
    chown -R root.root .
    perl Makefile.PL -y
    
    make || exit 1
    make install DESTDIR=$PKG || exit 1

    mkdir -p $PKG/usr/doc/$(basename $SRC)
    cp -a \
      AUTHORS COPYING INSTALL NEWS README TODO ChangeLog doc \
      $PKG/usr/doc/$(basename $SRC)
	  rm  $PKG/usr/lib/perl5/$perlversion/i486-linux-thread-multi/perllocal.pod
	#( cd $PKG ; makepkg  -l y -c n $PKG.txz )
	#installpkg $PKG.txz
	#rm -f $PKG.txz
	
  cd $PKGBUILD
done


# Strip everything:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


# Cleanup
( cd $PKG/usr/share
  mv man .. )
chmod 755 $PKG/usr/bin/*
chmod 644 $PKG/usr/man/man?/*
rm -rf $PKG/usr/share
cp -rf $PKG/usr/lib/perl5/site_perl/$perlversion/* $PKG/usr/lib/perl5/$perlversion/
rm -rf $PKG/usr/lib/perl5/site_perl/$perlversion/*

  
# Gzip man !
gzip -9 $PKG/usr/man/man?/*

cd $PKGBUILD

# Slack desc

mkdir -p $PKG/install

cat << "EOF" > $PKG/install/slack-desc
perl-gtk2:  perl-gtk2 (perl gnome bindings)
perl-gtk2:
perl-gtk2: This package contains ExtUtils-Depend and ExtUtils-PkgConfig as well
perl-gtk2: as the perl language bindings for glib2, gtk+2, cairo,
perl-gtk2: libgnome2, libgnome2-canvas, libgnome2-print, gnome2-gconf,
perl-gtk2: gnome2-vfs, glade-xml, gtk2-html and gtk2-sourceview
perl-gtk2:
perl-gtk2:
perl-gtk2:
perl-gtk2:
perl-gtk2:
EOF

# Welcome home

mkdir -p $PKG/usr/src/$NAME-$VERSION
cp $PKGBUILD/build-$NAME.sh $PKG/usr/src/$NAME-$VERSION/

# And finally, a package

cd $PKG
makepkg  -l y -c n $PKG.txz

# cleanup
rm -rf $PKG
rm -rf $TMP
#removepkg $PKG.txz

